﻿/*
 * Copyright (C)  2011  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.Windows.Forms;
using System.Drawing.Imaging;
using System.Collections.Generic;

namespace plexdata.ClipboardViewer
{
    internal class ExportFilter
    {
        public ExportFilter(string text, string filter, TextDataFormat format)
            : base()
        {
            this.Text = text;
            this.Filter = filter;
            this.TextFormat = format;
        }

        public ExportFilter(string text, string filter, ImageFormat format)
            : base()
        {
            this.Text = text;
            this.Filter = filter;
            this.ImageFormat = format;
        }

        public string Text { get; private set; }
        
        public string Filter { get; private set; }
        
        public TextDataFormat TextFormat { get; private set; }
        
        public ImageFormat ImageFormat { get; private set; }

        public override string ToString()
        {
            if (!String.IsNullOrEmpty(this.Text) && !String.IsNullOrEmpty(this.Filter))
            {
                return this.Text + "|" + this.Filter;
            }
            else
            {
                return base.ToString();
            }
        }

        public static ExportFilter AllFiles()
        {
            return new ExportFilter("All Files (*.*)", "*.*", TextDataFormat.Text);
        }

        public static string BuildFilters(List<ExportFilter> filters)
        {
            string result = "";
            if (filters != null && filters.Count > 0)
            {
                foreach (ExportFilter current in filters)
                {
                    result += current.ToString() + "|";
                }

                // Cutoff last pipe character!
                result = result.Substring(0, result.Length - 1);
            }
            return result;
        }
    }
}

// EOF