﻿/*
 * Copyright (C)  2011  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.IO;
using System.Drawing;
using System.Reflection;
using System.Diagnostics;
using System.Windows.Forms;
using System.Drawing.Imaging;
using System.Collections.Generic;

namespace plexdata.ClipboardViewer
{
    public partial class ImageViewDialog : Form
    {
        private List<ExportFilter> filters = new List<ExportFilter>();

        public ImageViewDialog()
        {
            this.InitializeComponent();
            this.Icon = Icon.FromHandle(plexdata.ClipboardViewer.Properties.Resources.MainIcon.GetHicon());

            this.filters.Add(new ExportFilter("PNG Files (*.png)", "*.png", ImageFormat.Png));
            this.filters.Add(new ExportFilter("JPG Files (*.jpg)", "*.jpg", ImageFormat.Jpeg));
            this.filters.Add(new ExportFilter("BMP Files (*.bmp)", "*.bmp", ImageFormat.Bmp));
            this.filters.Add(new ExportFilter("GIF Files (*.gif)", "*.gif", ImageFormat.Gif));
            this.filters.Add(ExportFilter.AllFiles());
        }

        public ImageViewDialog(MainForm parent)
            : this()
        {
            if (parent != null)
            {
                parent.ClipboardChanged += new EventHandler<EventArgs>(this.OnClipboardChanged);
            }
        }

        private void ImageViewDialog_Load(object sender, EventArgs args)
        {
            this.LoadData();
        }

        private void OnClipboardChanged(object sender, EventArgs args)
        {
            this.LoadData();
        }

        private void btnClose_Click(object sender, EventArgs args)
        {
            this.Close();
        }

        private void btnExport_Click(object sender, EventArgs args)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            dialog.Filter = ExportFilter.BuildFilters(this.filters);
            dialog.InitialDirectory = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
            dialog.RestoreDirectory = true;

            if (DialogResult.OK == dialog.ShowDialog(this))
            {
                try
                {
                    using (FileStream stream = File.Create(dialog.FileName))
                    {
                        Image image = Clipboard.GetImage();
                        image.Save(stream, this.filters[dialog.FilterIndex - 1].ImageFormat);
                        stream.Close();
                    }
                }
                catch (Exception exception)
                {
                    MessageBox.Show(
                        this, "File couldn't be saved!\n\n" + exception.ToString(),
                        "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void LoadData()
        {
            this.imageViewer.SetImage(Clipboard.GetImage());
        }
    }
}

// EOF