﻿/*
 * Copyright (C)  2011  Axel Kesseler
 * 
 * This software is free and you can use it for any purpose. Furthermore, 
 * you are free to copy, to modify and/or to redistribute this software.
 * 
 * In addition, this software is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

using System;
using System.IO;
using System.Drawing;
using System.Diagnostics;
using System.Windows.Forms;

namespace plexdata.ClipboardViewer
{
    // REMARK: Suppressing the drawing of the ugly Rich-Edit-Box border.
    //         The solution to use a panel that includes a Rich-Edit-Box 
    //         is good enough for my purposes! But if I ever need such a 
    //         Rich-Edit-Box that handles border style depending drawing 
    //         then I should check out the link below.
    //         http://www.codeproject.com/KB/edit/RichTextBoxEx.aspx
    internal class TextViewer : Panel
    {
        private TextViewerBox viewer = null;

        public TextViewer()
            : base()
        {
            this.BackColor = SystemColors.Window;

            this.viewer = new TextViewerBox();
            this.viewer.BorderStyle = BorderStyle.None;
            this.viewer.Dock = DockStyle.Fill;
            this.viewer.Multiline = true;
            this.viewer.WordWrap = false;
            this.viewer.ReadOnly = true;

            this.Controls.Add(this.viewer);
        }

        public void SetText(string text)
        {
            this.viewer.Rtf = "";
            this.viewer.Text = (text != null) ? text : "";
        }

        public void SetText(string text, bool rtf)
        {
            if (rtf)
            {
                this.viewer.Text = "";
                this.viewer.Rtf = (text != null) ? text : ""; ;
            }
            else
            {
                this.SetText(text);
            }
        }

        private class TextViewerBox : RichTextBox
        {
            public TextViewerBox()
                : base()
            {
                this.SetStyle(ControlStyles.DoubleBuffer, true);
                this.SetStyle(ControlStyles.ResizeRedraw, true);
            }

            public override Color BackColor
            {
                get
                {
                    if (base.ReadOnly && base.Parent != null)
                    {
                        return base.Parent.BackColor;
                    }
                    else
                    {
                        return base.BackColor;
                    }
                }
                set
                {
                    base.BackColor = value;
                }
            }

            protected override void WndProc(ref Message message)
            {
                const int WM_MOUSEWHEEL = 0x020A;

                switch (message.Msg)
                {
                    case WM_MOUSEWHEEL:

                        // Suppress zooming for mouse wheel messages.
                        if (this.IsControl())
                        {
                            // TODO: Scroll the Rich-Edit-Box horizontal...  
                            //       If you find a better/easier solution than 
                            //       suggested by sample below.
                            // http://www.codeproject.com/KB/cs/scrollingTextbox.aspx
                        }
                        else
                        {
                            base.WndProc(ref message);
                        }
                        break;

                    default:

                        base.WndProc(ref message);
                        break;
                }
            }

            private bool IsControl()
            {
                return ((Control.ModifierKeys & Keys.Control) == Keys.Control);
            }
        }
    }
}

// EOF